// preferences.hh - source file for the mailfilter program
// Copyright (c) 2000 - 2005  Andreas Bauer <baueran@in.tum.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

#ifndef PREFERENCES_HH
#define PREFERENCES_HH

#include <string>
#include <vector>
#include <fstream>
#include "defines.hh"
#include "socket.hh"
#include "filter.hh"
#include "score.hh"
#include "account.hh"

using namespace std;

class Preferences
{
protected:
  static ifstream         prefs_stream;
  static vector<Filter>   allows;
  static vector<Filter>   denies;
  static vector<Score>    scores;
  static vector<Account>  accnts;
  static Account          cur_account;
  static string           prefs_file_name;
  static string           log_file_name;
  static string           headers_file_name;
  static int              icase;
  static bool             norm;
  static bool             test;
  static bool             show_headers;
  static bool             del_duplicates;
  static bool             ret_status;
  static int              high_score;
  static unsigned         time_out_val;
  static int              max_size;
  static Size_score       size_score;
  static int              max_size_friends;
  static int              max_line_length;
  static int              rreg_type;
  static int              verbosity;
  static int              conn_type;
  static int              negative_allows;
  static int              negative_denies;
  static int              negative_scores;
  // These flags indicate whether a value was already set, or
  // whether it's still set to the default values defined by the
  // constructor.
  static bool             verbosity_changed;
  static bool             test_changed;
public:
  static void             init              (void);
  static void             kill              (void);
  static bool             open              (const char*);
  static bool             load              (void);
  static void             add_deny_rule     (const char*,
					     const char*,
					     const char*);
  static void             add_allow_rule    (const char*,
					     const char*,
					     const char*);
  static void             add_score         (const char*,
					     int,
					     const char*,
					     const char*);
  static int              neg_allows        (void);
  static int              neg_denies        (void);
  static void             set_rc_file       (const char*);
  static string           rc_file           (void);
  static void             set_log_file      (const char*);
  static string           log_file          (void);
  static void             set_verbose_level (int);
  static int              verbose_level     (void);
  static void             set_headers_file  (const char*);
  static string           headers_file      (void);
  static void             set_default_case  (const char*);
  static int              default_case      (void);
  static void             set_reg_type      (const char*);
  static int              reg_type          (void);
  static void             set_server        (const char*);
  static void             set_usr           (const char*);
  static void             set_passwd        (const char*);
  static void             set_protocol      (const char*);
  static void             set_connection    (unsigned int = POSIX_SOCKETS)
                                             __attribute__ ((unused));
  static void             set_port          (unsigned int);
  static unsigned int     time_out          (void);
  static void             set_time_out      (unsigned int);
  static bool             delete_duplicates (void);
  static void             set_del_duplicates(const char*);
  static int              max_size_allow    (void);
  static void             set_max_size_allow(int);
  static int              max_size_deny     (void);
  static void             set_max_size_deny (int);
  static Size_score       max_size_score    (void);
  static void             set_max_size_score(int, 
					     int);
  static int              highscore         (void);
  static void             set_highscore     (int);
  static bool             normal            (void);
  static void             set_normal        (const char*);
  static bool             test_mode         (void);
  static void             set_test_mode     (const char*);
  static int              maxlength         (void);
  static void             set_maxlength     (int);
  static bool             return_status     (void);
  static void             set_return_status (bool);
  static vector<Account>* accounts          (void);
  static vector<Filter>*  allow_filters     (void);
  static vector<Filter>*  deny_filters      (void);
  static vector<Score>*   score_filters     (void);
};

#endif
